@@ -3,29 +3,23 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1201';
+our $VERSION = '0.1300';
 
 use MIDI::Simple;
+use Music::Duration;
 use Moo;
 use strictures 2;
 use namespace::clean;
 
 
 sub BUILD {
-   my ( $self, $args ) = @_;
-
-    my ($beats, $divisions) = split /\//, $self->signature;
-    $self->beats($beats);
-    $self->divisions($divisions);
-    $self->score->time_signature(
-        $self->beats,
-        ( $self->divisions == 8 ? 3 : 2),
-        ( $self->divisions == 8 ? 24 : 18 ),
-        8
-    );
+    my ( $self, $args ) = @_;
 
     $self->score->noop( 'c' . $self->channel, 'V' . $self->volume );
+
     $self->score->set_tempo( int( 60_000_000 / $self->bpm ) );
+
+    $self->set_time_sig;
 }
 
 
@@ -89,17 +83,38 @@ has mute_triangle  => ( is => 'ro', default => sub { 'n80' } );
 has open_triangle  => ( is => 'ro', default => sub { 'n81' } );
 
 
-has whole             => ( is => 'ro', default => sub { 'wn' } );
-has half              => ( is => 'ro', default => sub { 'hn' } );
-has quarter           => ( is => 'ro', default => sub { 'qn' } );
-has triplet_quarter   => ( is => 'ro', default => sub { 'tqn' } );
-has dotted_quarter    => ( is => 'ro', default => sub { 'dqn' } );
-has eighth            => ( is => 'ro', default => sub { 'en' } );
-has triplet_eighth    => ( is => 'ro', default => sub { 'ten' } );
-has dotted_eighth     => ( is => 'ro', default => sub { 'den' } );
-has sixteenth         => ( is => 'ro', default => sub { 'sn' } );
-has triplet_sixteenth => ( is => 'ro', default => sub { 'tsn' } );
-has dotted_sixteenth  => ( is => 'ro', default => sub { 'dsn' } );
+has whole                         => (is => 'ro', default => sub { 'wn' });
+has triplet_whole                 => (is => 'ro', default => sub { 'twn' });
+has dotted_whole                  => (is => 'ro', default => sub { 'dwn' });
+has double_dotted_whole           => (is => 'ro', default => sub { 'ddwn' });
+has half                          => (is => 'ro', default => sub { 'hn' });
+has triplet_half                  => (is => 'ro', default => sub { 'thn' });
+has dotted_half                   => (is => 'ro', default => sub { 'dhn' });
+has double_dotted_half            => (is => 'ro', default => sub { 'ddhn' });
+has quarter                       => (is => 'ro', default => sub { 'qn' });
+has triplet_quarter               => (is => 'ro', default => sub { 'tqn' });
+has dotted_quarter                => (is => 'ro', default => sub { 'dqn' });
+has double_dotted_quarter         => (is => 'ro', default => sub { 'ddqn' });
+has eighth                        => (is => 'ro', default => sub { 'en' });
+has triplet_eighth                => (is => 'ro', default => sub { 'ten' });
+has dotted_eighth                 => (is => 'ro', default => sub { 'den' });
+has double_dotted_eighth          => (is => 'ro', default => sub { 'dden' });
+has sixteenth                     => (is => 'ro', default => sub { 'sn' });
+has triplet_sixteenth             => (is => 'ro', default => sub { 'tsn' });
+has dotted_sixteenth              => (is => 'ro', default => sub { 'dsn' });
+has double_dotted_sixteenth       => (is => 'ro', default => sub { 'ddsn' });
+has thirtysecond                  => (is => 'ro', default => sub { 'yn' });
+has triplet_thirtysecond          => (is => 'ro', default => sub { 'dyn' });
+has dotted_thirtysecond           => (is => 'ro', default => sub { 'dyn' });
+has double_dotted_thirtysecond    => (is => 'ro', default => sub { 'ddyn' });
+has sixtyfourth                   => (is => 'ro', default => sub { 'xn' });
+has triplet_sixtyfourth           => (is => 'ro', default => sub { 'dxn' });
+has dotted_sixtyfourth            => (is => 'ro', default => sub { 'dxn' });
+has double_dotted_sixtyfourth     => (is => 'ro', default => sub { 'ddxn' });
+has onetwentyeighth               => (is => 'ro', default => sub { 'on' });
+has triplet_onetwentyeighth       => (is => 'ro', default => sub { 'don' });
+has dotted_onetwentyeighth        => (is => 'ro', default => sub { 'don' });
+has double_dotted_onetwentyeighth => (is => 'ro', default => sub { 'ddon' });
 
 
 sub note { return shift->score->n(@_) }
@@ -256,11 +271,22 @@ sub metronome78 {
 }
 
 
+sub roll {
+    my ($self, $length, $spec, $patch) = @_;
+    $patch ||= $self->snare;
+    my $x = $MIDI::Simple::Length{$length};
+    my $y = $MIDI::Simple::Length{$spec};
+    my $z = sprintf '%0.f', $x / $y;
+    $self->note($spec, $patch) for 1 .. $z;
+}
+
+
 sub set_time_sig {
     my $self = shift;
-    my $signature = shift || $self->signature;
-    $self->signature($signature);
-    my ($beats, $divisions) = split /\//, $signature;
+    if (@_) {
+        $self->signature(shift);
+    }
+    my ($beats, $divisions) = split /\//, $self->signature;
     $self->beats($beats);
     $self->divisions($divisions);
     $self->score->time_signature(
@@ -291,7 +317,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1201
+version 0.1300
 
 =head1 SYNOPSIS
 
@@ -314,18 +340,22 @@ version 0.1201
 
  $d->rest($d->whole);
 
+ $d->roll($d->eighth, $d->thirtysecond);
+
  $d->metronome44;  # 4/4 time for the number of bars
 
  # Alternate kick and snare
- $d->note( $d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare )
+ $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
  $d->write;
 
 =head1 DESCRIPTION
 
-This module provides a MIDI drummer with the essentials to add notes to produce
-a MIDI score.
+This module provides handy defaults and tools to produce a MIDI score
+with drum parts.
+
+=for Pod::Coverage BUILD
 
 =head1 ATTRIBUTES
 
@@ -399,13 +429,21 @@ Computed given the B<signature>.
 
 =over 4
 
-=item whole, half
+=item whole, triplet_whole, dotted_whole, double_dotted_whole
 
-=item quarter, triplet_quarter, dotted_quarter
+=item half, triplet_half, dotted_half, double_dotted_half
 
-=item eighth, triplet_eighth, dotted_eighth
+=item quarter, triplet_quarter, dotted_quarter, double_dotted_quarter
 
-=item sixteenth, triplet_sixteenth, dotted_sixteenth
+=item eighth, triplet_eighth, dotted_eighth, double_dotted_eighth
+
+=item sixteenth, triplet_sixteenth, dotted_sixteenth, double_dotted_sixteenth
+
+=item thirtysecond, triplet_thirtysecond, dotted_thirtysecond, double_dotted_thirtysecond
+
+=item sixtyfourth, triplet_sixtyfourth, dotted_sixtyfourth, double_dotted_sixtyfourth
+
+=item onetwentyeighth, triplet_onetwentyeighth, dotted_onetwentyeighth, double_dotted_onetwentyeighth
 
 =back
 
@@ -417,8 +455,6 @@ Computed given the B<signature>.
 
 Return a new C<MIDI::Drummer::Tiny> object.
 
-=for Pod::Coverage BUILD
-
 =head2 note
 
  $d->note( $d->quarter, $d->closed_hh, $d->kick );
@@ -509,6 +545,15 @@ Add a 7/4 beat to the score.
 
 Add a 7/8 beat to the score.
 
+=head2 roll
+
+  $d->roll( $length, $spec, $patch );
+
+Add a drum roll to the score, where the B<patch> is played for
+duration B<length> in B<spec> increments.
+
+If not provided the B<snare> is used for the B<patch>.
+
 =head2 set_time_sig
 
   $d->set_time_sig('5/4');
@@ -523,12 +568,16 @@ constuctor.
 
 =head1 SEE ALSO
 
-The F<eg/*> programs in this distribution
+The F<eg/*> programs in this distribution and
+F<eg/drum-fills-advanced> in the L<Music::Duration::Partition>
+distribution
 
 L<Moo>
 
 L<MIDI::Simple>
 
+L<Music::Duration>
+
 L<https://en.wikipedia.org/wiki/General_MIDI#Percussion>
 
 =head1 AUTHOR
